@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 
-our $VERSION = '0.14.11';
+our $VERSION = 'v0.14.12';
 
 
 1;
@@ -22,7 +22,7 @@ screenplays.
 
 =head1 VERSION
 
-version 0.14.11
+version v0.14.12
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ The rest of this page will document the syntax of the custom textual format.
 
 =head1 VERSION
 
-Version 0.14.11
+Version 0.14.12
 
 =head1 FORMAT
 
@@ -206,8 +206,9 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction or by email to
-bug-xml-grammar-fiction@rt.cpan.org.
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction> or by email
+to
+L<bug-xml-grammar-fiction@rt.cpan.org|mailto:bug-xml-grammar-fiction@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -252,7 +253,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-Grammar-Fiction>
 
 =item *
 
@@ -284,7 +285,7 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/XML-Grammar-Fiction>
+L<http://cpants.cpanauthors.org/dist/XML-Grammar-Fiction>
 
 =item *
 
@@ -315,7 +316,7 @@ L<http://deps.cpantesters.org/?module=XML::Grammar::Fiction>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-xml-grammar-fiction at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fiction>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-Grammar-Fiction>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
